pub struct BaseImage {
pub layer_count: Option<i32>,
pub name: Option<String>,
pub repository: Option<String>,
}Expand description
BaseImage describes a base image of a container image.
This type is not used in any activity, and only used as part of another schema.
Fields
layer_count: Option<i32>The number of layers that the base image is composed of.
name: Option<String>The name of the base image.
repository: Option<String>The repository name in which the base image is from.