pub struct BatchCreateNotesRequest {
pub notes: Option<HashMap<String, Note>>,
}Expand description
Request to create notes in batch.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notes batch create projects (request)
Fields
notes: Option<HashMap<String, Note>>Required. The notes to create. Max allowed length is 1000.