pub struct BatchCreateNotesResponse {
pub notes: Option<Vec<Note>>,
}Expand description
Response for creating notes in batch.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notes batch create projects (response)
Fields
notes: Option<Vec<Note>>The notes that were created.