pub struct BuildOccurrence {
    pub intoto_provenance: Option<InTotoProvenance>,
    pub intoto_statement: Option<InTotoStatement>,
    pub provenance: Option<BuildProvenance>,
    pub provenance_bytes: Option<String>,
}
Details of a build occurrence.

This type is not used in any activity, and only used as part of another schema.

Fields

intoto_provenance: Option<InTotoProvenance>

Deprecated. See InTotoStatement for the replacement. In-toto Provenance representation as defined in spec.

intoto_statement: Option<InTotoStatement>

In-toto Statement representation as defined in spec. The intoto_statement can contain any type of provenance. The serialized payload of the statement can be stored and signed in the Occurrence’s envelope.

provenance: Option<BuildProvenance>

The actual provenance for the build.

provenance_bytes: Option<String>

Serialized JSON representation of the provenance, used in generating the build signature in the corresponding build note. After verifying the signature, provenance_bytes can be unmarshalled and compared to the provenance to confirm that it is unchanged. A base64-encoded string representation of the provenance bytes is used for the signature in order to interoperate with openssl which expects this format for signature verification. The serialized form is captured both to avoid ambiguity in how the provenance is marshalled to json as well to prevent incompatibilities with future changes.