Struct google_containeranalysis1::api::BuildProvenance
source · [−]pub struct BuildProvenance {Show 13 fields
pub build_options: Option<HashMap<String, String>>,
pub builder_version: Option<String>,
pub built_artifacts: Option<Vec<Artifact>>,
pub commands: Option<Vec<Command>>,
pub create_time: Option<String>,
pub creator: Option<String>,
pub end_time: Option<String>,
pub id: Option<String>,
pub logs_uri: Option<String>,
pub project_id: Option<String>,
pub source_provenance: Option<Source>,
pub start_time: Option<String>,
pub trigger_id: Option<String>,
}Expand description
Provenance of a build. Contains all information needed to verify the full details about the build from source to completion.
This type is not used in any activity, and only used as part of another schema.
Fields
build_options: Option<HashMap<String, String>>Special options applied to this build. This is a catch-all field where build providers can enter any desired additional details.
builder_version: Option<String>Version string of the builder at the time this build was executed.
built_artifacts: Option<Vec<Artifact>>Output of the build.
commands: Option<Vec<Command>>Commands requested by the build.
create_time: Option<String>Time at which the build was created.
creator: Option<String>E-mail address of the user who initiated this build. Note that this was the user’s e-mail address at the time the build was initiated; this address may not represent the same end-user for all time.
end_time: Option<String>Time at which execution of the build was finished.
id: Option<String>Required. Unique identifier of the build.
logs_uri: Option<String>URI where any logs for this provenance were written.
project_id: Option<String>ID of the project.
source_provenance: Option<Source>Details of the Source input to the build.
start_time: Option<String>Time at which execution of the build was started.
trigger_id: Option<String>Trigger identifier if the build was triggered automatically; empty if not.