pub struct CISAKnownExploitedVulnerabilities {
pub known_ransomware_campaign_use: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
known_ransomware_campaign_use: Option<String>Whether the vulnerability is known to have been leveraged as part of a ransomware campaign.