pub struct CloudRepoSourceContext {
pub alias_context: Option<AliasContext>,
pub repo_id: Option<RepoId>,
pub revision_id: Option<String>,
}Expand description
A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo.
This type is not used in any activity, and only used as part of another schema.
Fields
alias_context: Option<AliasContext>An alias, which may be a branch or tag.
repo_id: Option<RepoId>The ID of the repo.
revision_id: Option<String>A revision ID.