pub struct CloudStorageLocation { /* private fields */ }Expand description
Empty placeholder to denote that this is a Google Cloud Storage export request.
This type is not used in any activity, and only used as part of another schema.