Struct google_containeranalysis1::api::Command
source · [−]pub struct Command {
pub args: Option<Vec<String>>,
pub dir: Option<String>,
pub env: Option<Vec<String>>,
pub id: Option<String>,
pub name: Option<String>,
pub wait_for: Option<Vec<String>>,
}Expand description
Command describes a step performed as part of the build pipeline.
This type is not used in any activity, and only used as part of another schema.
Fields
args: Option<Vec<String>>Command-line arguments used when executing this command.
dir: Option<String>Working directory (relative to project source root) used when running this command.
env: Option<Vec<String>>Environment variables set before running this command.
id: Option<String>Optional unique identifier for this command, used in wait_for to reference this command as a dependency.
name: Option<String>Required. Name of the command, as presented on the command line, or if the command is packaged as a Docker container, as presented to docker pull.
wait_for: Option<Vec<String>>The ID(s) of the command(s) that this command depends on.