Struct google_containeranalysis1::api::ComplianceNote
source · pub struct ComplianceNote {
pub cis_benchmark: Option<CisBenchmark>,
pub description: Option<String>,
pub rationale: Option<String>,
pub remediation: Option<String>,
pub scan_instructions: Option<Vec<u8>>,
pub title: Option<String>,
pub version: Option<Vec<ComplianceVersion>>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
cis_benchmark: Option<CisBenchmark>no description provided
description: Option<String>A description about this compliance check.
rationale: Option<String>A rationale for the existence of this compliance check.
remediation: Option<String>A description of remediation steps if the compliance check fails.
scan_instructions: Option<Vec<u8>>Serialized scan instructions with a predefined format.
title: Option<String>The title that identifies this compliance check.
version: Option<Vec<ComplianceVersion>>The OS and config versions the benchmark applies to.