pub struct DSSEHint {
    pub human_readable_name: Option<String>,
}
This submessage provides human-readable hints about the purpose of the authority. Because the name of a note acts as its resource reference, it is important to disambiguate the canonical name of the Note (which might be a UUID for security purposes) from “readable” names more suitable for debug output. Note that these hints should not be used to look up authorities in security sensitive contexts, such as when looking up attestations to verify.

This type is not used in any activity, and only used as part of another schema.

Fields

human_readable_name: Option<String>

Required. The human readable name of this attestation authority, for example “cloudbuild-prod”.