Struct google_containeranalysis1::api::DeploymentNote
source · pub struct DeploymentNote {
pub resource_uri: Option<Vec<String>>,
}Expand description
An artifact that can be deployed in some runtime.
This type is not used in any activity, and only used as part of another schema.
Fields
resource_uri: Option<Vec<String>>Required. Resource URI for the artifact being deployed.