pub struct DeploymentOccurrence {
    pub address: Option<String>,
    pub config: Option<String>,
    pub deploy_time: Option<String>,
    pub platform: Option<String>,
    pub resource_uri: Option<Vec<String>>,
    pub undeploy_time: Option<String>,
    pub user_email: Option<String>,
}
The period during which some deployable was active in a runtime.

This type is not used in any activity, and only used as part of another schema.

Fields

address: Option<String>

Address of the runtime element hosting this deployment.

config: Option<String>

Configuration used to create this deployment.

deploy_time: Option<String>

Required. Beginning of the lifetime of this deployment.

platform: Option<String>

Platform hosting this deployment.

resource_uri: Option<Vec<String>>

Output only. Resource URI for the artifact being deployed taken from the deployable field with the same name.

undeploy_time: Option<String>

End of the lifetime of this deployment.

user_email: Option<String>

Identity of the user that triggered this deployment.