Struct google_containeranalysis1::api::DiscoveryNote
source · [−]Expand description
A note that indicates a type of analysis a provider would perform. This note exists in a provider’s project. A Discovery occurrence is created in a consumer’s project at the start of analysis.
This type is not used in any activity, and only used as part of another schema.
Fields
analysis_kind: Option<String>Required. Immutable. The kind of analysis that is handled by this discovery.