pub struct DiscoveryOccurrence {
    pub analysis_status: Option<String>,
    pub analysis_status_error: Option<Status>,
    pub archive_time: Option<String>,
    pub continuous_analysis: Option<String>,
    pub cpe: Option<String>,
    pub last_scan_time: Option<String>,
}
Provides information about the analysis status of a discovered resource.

This type is not used in any activity, and only used as part of another schema.

Fields

analysis_status: Option<String>

The status of discovery for the resource.

analysis_status_error: Option<Status>

When an error is encountered this will contain a LocalizedMessage under details to show to the user. The LocalizedMessage is output only and populated by the API.

archive_time: Option<String>

Output only. The time occurrences related to this discovery occurrence were archived.

continuous_analysis: Option<String>

Whether the resource is continuously analyzed.

cpe: Option<String>

The CPE of the resource being scanned.

last_scan_time: Option<String>

The last time this resource was scanned.