Struct google_containeranalysis1::api::ExportSBOMResponse
source · pub struct ExportSBOMResponse {
pub discovery_occurrence: Option<String>,
}Expand description
The response from a call to ExportSBOM.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations resources export sbom projects (response)
- resources export sbom projects (response)
Fields
discovery_occurrence: Option<String>The name of the discovery occurrence in the form “projects/{project_id}/occurrences/{OCCURRENCE_ID} It can be used to track the progress of the SBOM export.