Struct google_containeranalysis1::api::FileHashes
source · [−]Expand description
Container message for hashes of byte content of files, used in source messages to verify integrity of source input to the build.
This type is not used in any activity, and only used as part of another schema.
Fields
file_hash: Option<Vec<Hash>>Required. Collection of file hashes.