Struct google_containeranalysis1::api::Fingerprint
source · [−]pub struct Fingerprint {
pub v1_name: Option<String>,
pub v2_blob: Option<Vec<String>>,
pub v2_name: Option<String>,
}Expand description
A set of properties that uniquely identify a given Docker image.
This type is not used in any activity, and only used as part of another schema.
Fields
v1_name: Option<String>Required. The layer ID of the final layer in the Docker image’s v1 representation.
v2_blob: Option<Vec<String>>Required. The ordered list of v2 blobs that represent a given image.
v2_name: Option<String>Output only. The name of the image’s v2 blobs computed via: [bottom] := v2_blobbottom := sha256(v2_blob[N] + “ “ + v2_name[N+1]) Only the name of the final blob is kept.