Struct google_containeranalysis1::api::GitSourceContext
source · [−]Expand description
A GitSourceContext denotes a particular revision in a third party Git repository (e.g., GitHub).
This type is not used in any activity, and only used as part of another schema.
Fields
revision_id: Option<String>Git commit hash.
url: Option<String>Git repository URL.