pub struct GrafeasV1FileLocation {
pub file_path: Option<String>,
}Expand description
Indicates the location at which a package was found.
This type is not used in any activity, and only used as part of another schema.
Fields
file_path: Option<String>For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.