Struct google_containeranalysis1::api::Layer
source · pub struct Layer {
pub arguments: Option<String>,
pub directive: Option<String>,
}Expand description
Layer holds metadata specific to a layer of a Docker image.
This type is not used in any activity, and only used as part of another schema.
Fields
arguments: Option<String>The recovered arguments to the Dockerfile directive.
directive: Option<String>Required. The recovered Dockerfile directive used to construct this layer. See https://docs.docker.com/engine/reference/builder/ for more information.