Struct google_containeranalysis1::api::License
source · pub struct License {
pub comments: Option<String>,
pub expression: Option<String>,
}Expand description
License information.
This type is not used in any activity, and only used as part of another schema.
Fields
comments: Option<String>Comments
expression: Option<String>Often a single license can be used to represent the licensing terms. Sometimes it is necessary to include a choice of one or more licenses or some combination of license identifiers. Examples: “LGPL-2.1-only OR MIT”, “LGPL-2.1-only AND MIT”, “GPL-2.0-or-later WITH Bison-exception-2.2”.