pub struct ListNoteOccurrencesResponse {
pub next_page_token: Option<String>,
pub occurrences: Option<Vec<Occurrence>>,
}Expand description
Response for listing occurrences for a note.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notes occurrences list projects (response)
Fields
next_page_token: Option<String>Token to provide to skip to a particular spot in the list.
occurrences: Option<Vec<Occurrence>>The occurrences attached to the specified note.