pub struct Metadata {
    pub build_finished_on: Option<String>,
    pub build_invocation_id: Option<String>,
    pub build_started_on: Option<String>,
    pub completeness: Option<Completeness>,
    pub reproducible: Option<bool>,
}
Other properties of the build.

This type is not used in any activity, and only used as part of another schema.

Fields

build_finished_on: Option<String>

The timestamp of when the build completed.

build_invocation_id: Option<String>

Identifies the particular build invocation, which can be useful for finding associated logs or other ad-hoc analysis. The value SHOULD be globally unique, per in-toto Provenance spec.

build_started_on: Option<String>

The timestamp of when the build started.

completeness: Option<Completeness>

Indicates that the builder claims certain fields in this message to be complete.

reproducible: Option<bool>

If true, the builder claims that running the recipe on materials will produce bit-for-bit identical output.