pub struct NonCompliantFile {
    pub display_command: Option<String>,
    pub path: Option<String>,
    pub reason: Option<String>,
}
Details about files that caused a compliance check to fail. display_command is a single command that can be used to display a list of non compliant files. When there is no such command, we can also iterate a list of non compliant file using ‘path’.

This type is not used in any activity, and only used as part of another schema.

Fields

display_command: Option<String>

Command to display the non-compliant files.

path: Option<String>

Empty if display_command is set.

reason: Option<String>

Explains why a file is non compliant for a CIS check.