pub struct Note {Show 22 fields
pub attestation: Option<AttestationNote>,
pub build: Option<BuildNote>,
pub compliance: Option<ComplianceNote>,
pub create_time: Option<DateTime<Utc>>,
pub deployment: Option<DeploymentNote>,
pub discovery: Option<DiscoveryNote>,
pub dsse_attestation: Option<DSSEAttestationNote>,
pub expiration_time: Option<DateTime<Utc>>,
pub image: Option<ImageNote>,
pub kind: Option<String>,
pub long_description: Option<String>,
pub name: Option<String>,
pub package: Option<PackageNote>,
pub related_note_names: Option<Vec<String>>,
pub related_url: Option<Vec<RelatedUrl>>,
pub sbom_reference: Option<SBOMReferenceNote>,
pub secret: Option<SecretNote>,
pub short_description: Option<String>,
pub update_time: Option<DateTime<Utc>>,
pub upgrade: Option<UpgradeNote>,
pub vulnerability: Option<VulnerabilityNote>,
pub vulnerability_assessment: Option<VulnerabilityAssessmentNote>,
}Expand description
A type of analysis that can be done for a resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations notes create projects (request|response)
- locations notes get projects (response)
- locations notes patch projects (request|response)
- locations occurrences get notes projects (response)
- notes create projects (request|response)
- notes get projects (response)
- notes patch projects (request|response)
- occurrences get notes projects (response)
Fields
attestation: Option<AttestationNote>A note describing an attestation role.
build: Option<BuildNote>A note describing build provenance for a verifiable build.
compliance: Option<ComplianceNote>A note describing a compliance check.
create_time: Option<DateTime<Utc>>Output only. The time this note was created. This field can be used as a filter in list requests.
deployment: Option<DeploymentNote>A note describing something that can be deployed.
discovery: Option<DiscoveryNote>A note describing the initial analysis of a resource.
dsse_attestation: Option<DSSEAttestationNote>A note describing a dsse attestation note.
expiration_time: Option<DateTime<Utc>>Time of expiration for this note. Empty if note does not expire.
image: Option<ImageNote>A note describing a base image.
kind: Option<String>Output only. The type of analysis. This field can be used as a filter in list requests.
long_description: Option<String>A detailed description of this note.
name: Option<String>Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID].
package: Option<PackageNote>A note describing a package hosted by various package managers.
Other notes related to this note.
URLs associated with this note.
sbom_reference: Option<SBOMReferenceNote>A note describing an SBOM reference.
secret: Option<SecretNote>A note describing a secret.
short_description: Option<String>A one sentence description of this note.
update_time: Option<DateTime<Utc>>Output only. The time this note was last updated. This field can be used as a filter in list requests.
upgrade: Option<UpgradeNote>A note describing available package upgrades.
vulnerability: Option<VulnerabilityNote>A note describing a package vulnerability.
vulnerability_assessment: Option<VulnerabilityAssessmentNote>A note describing a vulnerability assessment.