Struct google_containeranalysis1::api::PackageNote
source · [−]pub struct PackageNote {
pub distribution: Option<Vec<Distribution>>,
pub name: Option<String>,
}Expand description
This represents a particular package that is distributed over various channels. E.g., glibc (aka libc6) is distributed by many, at various versions.
This type is not used in any activity, and only used as part of another schema.
Fields
distribution: Option<Vec<Distribution>>The various channels by which a package is distributed.
name: Option<String>Required. Immutable. The name of the package.