Struct google_containeranalysis1::api::PackageOccurrence
source · [−]Expand description
Details on how a particular software package was installed on a system.
This type is not used in any activity, and only used as part of another schema.
Fields
location: Option<Vec<Location>>Required. All of the places within the filesystem versions of this package have been found.
name: Option<String>Output only. The name of the installed package.