Struct google_containeranalysis1::api::ProjectRepoId
source · pub struct ProjectRepoId {
pub project_id: Option<String>,
pub repo_name: Option<String>,
}Expand description
Selects a repo using a Google Cloud Platform project ID (e.g., winged-cargo-31) and a repo name within that project.
This type is not used in any activity, and only used as part of another schema.
Fields
project_id: Option<String>The ID of the project.
repo_name: Option<String>The name of the repo. Leave empty for the default repo.