pub struct Risk {
pub cisa_kev: Option<CISAKnownExploitedVulnerabilities>,
pub epss: Option<ExploitPredictionScoringSystem>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
cisa_kev: Option<CISAKnownExploitedVulnerabilities>CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild.
epss: Option<ExploitPredictionScoringSystem>The Exploit Prediction Scoring System (EPSS) estimates the likelihood (probability) that a software vulnerability will be exploited in the wild.