Struct google_containeranalysis1::api::SlsaCompleteness
source · [−]pub struct SlsaCompleteness {
pub arguments: Option<bool>,
pub environment: Option<bool>,
pub materials: Option<bool>,
}Expand description
Indicates that the builder claims certain fields in this message to be complete.
This type is not used in any activity, and only used as part of another schema.
Fields
arguments: Option<bool>If true, the builder claims that recipe.arguments is complete, meaning that all external inputs are properly captured in the recipe.
environment: Option<bool>If true, the builder claims that recipe.environment is claimed to be complete.
materials: Option<bool>If true, the builder claims that materials are complete, usually through some controls to prevent network access. Sometimes called “hermetic”.