pub struct Source {
    pub additional_contexts: Option<Vec<SourceContext>>,
    pub artifact_storage_source_uri: Option<String>,
    pub context: Option<SourceContext>,
    pub file_hashes: Option<HashMap<String, FileHashes>>,
}
Source describes the location of the source used for the build.

This type is not used in any activity, and only used as part of another schema.

Fields

additional_contexts: Option<Vec<SourceContext>>

If provided, some of the source code used for the build may be found in these locations, in the case where the source repository had multiple remotes or submodules. This list will not include the context specified in the context field.

artifact_storage_source_uri: Option<String>

If provided, the input binary artifacts for the build came from this location.

context: Option<SourceContext>

If provided, the source code used for the build came from this location.

file_hashes: Option<HashMap<String, FileHashes>>

Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build. The keys to this map are file paths used as build source and the values contain the hash values for those files. If the build source came in a single package such as a gzipped tarfile (.tar.gz), the FileHash will be for the single path to that file.