Struct google_containeranalysis1::api::SourceContext
source · [−]pub struct SourceContext {
pub cloud_repo: Option<CloudRepoSourceContext>,
pub gerrit: Option<GerritSourceContext>,
pub git: Option<GitSourceContext>,
pub labels: Option<HashMap<String, String>>,
}Expand description
A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.
This type is not used in any activity, and only used as part of another schema.
Fields
cloud_repo: Option<CloudRepoSourceContext>A SourceContext referring to a revision in a Google Cloud Source Repo.
gerrit: Option<GerritSourceContext>A SourceContext referring to a Gerrit project.
git: Option<GitSourceContext>A SourceContext referring to any third party Git repo (e.g., GitHub).
labels: Option<HashMap<String, String>>Labels with user defined metadata.