Struct google_containeranalysis1::api::UpgradeDistribution
source · [−]pub struct UpgradeDistribution {
pub classification: Option<String>,
pub cpe_uri: Option<String>,
pub cve: Option<Vec<String>>,
pub severity: Option<String>,
}Expand description
The Upgrade Distribution represents metadata about the Upgrade for each operating system (CPE). Some distributions have additional metadata around updates, classifying them into various categories and severities.
This type is not used in any activity, and only used as part of another schema.
Fields
classification: Option<String>The operating system classification of this Upgrade, as specified by the upstream operating system upgrade feed. For Windows the classification is one of the category_ids listed at https://docs.microsoft.com/en-us/previous-versions/windows/desktop/ff357803(v=vs.85)
cpe_uri: Option<String>Required - The specific operating system this metadata applies to. See https://cpe.mitre.org/specification/.
cve: Option<Vec<String>>The cve tied to this Upgrade.
severity: Option<String>The severity as specified by the upstream operating system.