pub struct UpgradeNote {
    pub distributions: Option<Vec<UpgradeDistribution>>,
    pub package: Option<String>,
    pub version: Option<Version>,
    pub windows_update: Option<WindowsUpdate>,
}
An Upgrade Note represents a potential upgrade of a package to a given version. For each package version combination (i.e. bash 4.0, bash 4.1, bash 4.1.2), there will be an Upgrade Note. For Windows, windows_update field represents the information related to the update.

This type is not used in any activity, and only used as part of another schema.

Fields

distributions: Option<Vec<UpgradeDistribution>>

Metadata about the upgrade for each specific operating system.

package: Option<String>

Required for non-Windows OS. The package this Upgrade is for.

version: Option<Version>

Required for non-Windows OS. The version of the package in machine + human readable form.

windows_update: Option<WindowsUpdate>

Required for Windows OS. Represents the metadata about the Windows update.