pub struct UpgradeOccurrence {
    pub distribution: Option<UpgradeDistribution>,
    pub package: Option<String>,
    pub parsed_version: Option<Version>,
    pub windows_update: Option<WindowsUpdate>,
}
An Upgrade Occurrence represents that a specific resource_url could install a specific upgrade. This presence is supplied via local sources (i.e. it is present in the mirror and the running system has noticed its availability). For Windows, both distribution and windows_update contain information for the Windows update.

This type is not used in any activity, and only used as part of another schema.

Fields

distribution: Option<UpgradeDistribution>

Metadata about the upgrade for available for the specific operating system for the resource_url. This allows efficient filtering, as well as making it easier to use the occurrence.

package: Option<String>

Required for non-Windows OS. The package this Upgrade is for.

parsed_version: Option<Version>

Required for non-Windows OS. The version of the package in a machine + human readable form.

windows_update: Option<WindowsUpdate>

Required for Windows OS. Represents the metadata about the Windows update.