Struct google_containeranalysis1::api::Version
source · [−]pub struct Version {
pub epoch: Option<i32>,
pub full_name: Option<String>,
pub inclusive: Option<bool>,
pub kind: Option<String>,
pub name: Option<String>,
pub revision: Option<String>,
}Expand description
Version contains structured information about the version of a package.
This type is not used in any activity, and only used as part of another schema.
Fields
epoch: Option<i32>Used to correct mistakes in the version numbering scheme.
full_name: Option<String>Human readable version string. This string is of the form :- and is only set when kind is NORMAL.
inclusive: Option<bool>Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range.
kind: Option<String>Required. Distinguishes between sentinel MIN/MAX versions and normal versions.
name: Option<String>Required only when version kind is NORMAL. The main part of the version name.
revision: Option<String>The iteration of the package build from the above version.