pub struct VexAssessment {
pub cve: Option<String>,
pub impacts: Option<Vec<String>>,
pub justification: Option<Justification>,
pub note_name: Option<String>,
pub related_uris: Option<Vec<RelatedUrl>>,
pub remediations: Option<Vec<Remediation>>,
pub state: Option<String>,
pub vulnerability_id: Option<String>,
}Expand description
VexAssessment provides all publisher provided Vex information that is related to this vulnerability.
This type is not used in any activity, and only used as part of another schema.
Fields
cve: Option<String>Holds the MITRE standard Common Vulnerabilities and Exposures (CVE) tracking number for the vulnerability. Deprecated: Use vulnerability_id instead to denote CVEs.
impacts: Option<Vec<String>>Contains information about the impact of this vulnerability, this will change with time.
justification: Option<Justification>Justification provides the justification when the state of the assessment if NOT_AFFECTED.
note_name: Option<String>The VulnerabilityAssessment note from which this VexAssessment was generated. This will be of the form: projects/[PROJECT_ID]/notes/[NOTE_ID].
Holds a list of references associated with this vulnerability item and assessment.
remediations: Option<Vec<Remediation>>Specifies details on how to handle (and presumably, fix) a vulnerability.
state: Option<String>Provides the state of this Vulnerability assessment.
vulnerability_id: Option<String>The vulnerability identifier for this Assessment. Will hold one of common identifiers e.g. CVE, GHSA etc.