pub struct VulnerabilityNote {
    pub cvss_score: Option<f32>,
    pub cvss_v3: Option<CVSSv3>,
    pub details: Option<Vec<Detail>>,
    pub severity: Option<String>,
    pub source_update_time: Option<String>,
    pub windows_details: Option<Vec<WindowsDetail>>,
}
A security vulnerability that can be found in resources.

This type is not used in any activity, and only used as part of another schema.

Fields

cvss_score: Option<f32>

The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity.

cvss_v3: Option<CVSSv3>

The full description of the CVSSv3 for this vulnerability.

details: Option<Vec<Detail>>

Details of all known distros and packages affected by this vulnerability.

severity: Option<String>

The note provider assigned severity of this vulnerability.

source_update_time: Option<String>

The time this information was last changed at the source. This is an upstream timestamp from the underlying information source - e.g. Ubuntu security tracker.

windows_details: Option<Vec<WindowsDetail>>

Windows details get their own format because the information format and model don’t match a normal detail. Specifically Windows updates are done as patches, thus Windows vulnerabilities really are a missing package, rather than a package being at an incorrect version.