pub struct VulnerabilityOccurrence {
pub cvss_score: Option<f32>,
pub cvssv3: Option<CVSS>,
pub effective_severity: Option<String>,
pub fix_available: Option<bool>,
pub long_description: Option<String>,
pub package_issue: Option<Vec<PackageIssue>>,
pub related_urls: Option<Vec<RelatedUrl>>,
pub severity: Option<String>,
pub short_description: Option<String>,
pub type_: Option<String>,
}Expand description
An occurrence of a severity vulnerability on a resource.
This type is not used in any activity, and only used as part of another schema.
Fields
cvss_score: Option<f32>Output only. The CVSS score of this vulnerability. CVSS score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity.
cvssv3: Option<CVSS>The cvss v3 score for the vulnerability.
effective_severity: Option<String>The distro assigned severity for this vulnerability when it is available, otherwise this is the note provider assigned severity. When there are multiple PackageIssues for this vulnerability, they can have different effective severities because some might be provided by the distro while others are provided by the language ecosystem for a language pack. For this reason, it is advised to use the effective severity on the PackageIssue level. In the case where multiple PackageIssues have differing effective severities, this field should be the highest severity for any of the PackageIssues.
fix_available: Option<bool>Output only. Whether at least one of the affected packages has a fix available.
long_description: Option<String>Output only. A detailed description of this vulnerability.
package_issue: Option<Vec<PackageIssue>>Required. The set of affected locations and their fixes (if available) within the associated resource.
Output only. URLs related to this vulnerability.
severity: Option<String>Output only. The note provider assigned severity of this vulnerability.
short_description: Option<String>Output only. A one sentence description of this vulnerability.
type_: Option<String>The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).