pub struct VulnerabilityOccurrencesSummary {
pub counts: Option<Vec<FixableTotalByDigest>>,
}Expand description
A summary of how many vulnerability occurrences there are per resource and severity type.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
counts: Option<Vec<FixableTotalByDigest>>A listing by resource of the number of fixable and total vulnerabilities.