Struct google_containeranalysis1::api::BuildNote
source · pub struct BuildNote {
pub builder_version: Option<String>,
}Expand description
Note holding the version of the provider’s builder and the signature of the provenance message in the build details occurrence.
This type is not used in any activity, and only used as part of another schema.
Fields
builder_version: Option<String>Required. Immutable. Version of the builder which produced this build.