Struct google_containeranalysis1::api::CVSS
source · [−]pub struct CVSS {
pub attack_complexity: Option<String>,
pub attack_vector: Option<String>,
pub authentication: Option<String>,
pub availability_impact: Option<String>,
pub base_score: Option<f32>,
pub confidentiality_impact: Option<String>,
pub exploitability_score: Option<f32>,
pub impact_score: Option<f32>,
pub integrity_impact: Option<String>,
pub privileges_required: Option<String>,
pub scope: Option<String>,
pub user_interaction: Option<String>,
}Expand description
Common Vulnerability Scoring System. For details, see https://www.first.org/cvss/specification-document This is a message we will try to use for storing multiple versions of CVSS. The intention is that as new versions of CVSS scores get added, we will be able to modify this message rather than adding new protos for each new version of the score.
This type is not used in any activity, and only used as part of another schema.
Fields
attack_complexity: Option<String>no description provided
attack_vector: Option<String>Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments.
authentication: Option<String>no description provided
availability_impact: Option<String>no description provided
base_score: Option<f32>The base score is a function of the base metric scores.
confidentiality_impact: Option<String>no description provided
exploitability_score: Option<f32>no description provided
impact_score: Option<f32>no description provided
integrity_impact: Option<String>no description provided
privileges_required: Option<String>no description provided
scope: Option<String>no description provided
user_interaction: Option<String>no description provided