pub struct ComplianceOccurrence {
pub non_compliance_reason: Option<String>,
pub non_compliant_files: Option<Vec<NonCompliantFile>>,
}Expand description
An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.
This type is not used in any activity, and only used as part of another schema.
Fields
non_compliance_reason: Option<String>no description provided
non_compliant_files: Option<Vec<NonCompliantFile>>no description provided