Struct google_containeranalysis1::api::ComplianceVersion
source · [−]Expand description
Describes the CIS benchmark version that is applicable to a given OS and os version.
This type is not used in any activity, and only used as part of another schema.
Fields
cpe_uri: Option<String>The CPE URI (https://cpe.mitre.org/specification/) this benchmark is applicable to.
version: Option<String>The version of the benchmark. This is set to the version of the OS-specific CIS document the benchmark is defined in.