Struct google_containeranalysis1::api::DSSEAttestationNote
source · [−]Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
hint: Option<DSSEHint>DSSEHint hints at the purpose of the attestation authority.