pub struct DSSEAttestationOccurrence {
pub envelope: Option<Envelope>,
pub statement: Option<InTotoStatement>,
}Expand description
Deprecated. Prefer to use a regular Occurrence, and populate the Envelope at the top level of the Occurrence.
This type is not used in any activity, and only used as part of another schema.
Fields
envelope: Option<Envelope>If doing something security critical, make sure to verify the signatures in this metadata.
statement: Option<InTotoStatement>no description provided