Struct google_containeranalysis1::api::Distribution
source · pub struct Distribution {
pub architecture: Option<String>,
pub cpe_uri: Option<String>,
pub description: Option<String>,
pub latest_version: Option<Version>,
pub maintainer: Option<String>,
pub url: Option<String>,
}Expand description
This represents a particular channel of distribution for a given package. E.g., Debian’s jessie-backports dpkg mirror.
This type is not used in any activity, and only used as part of another schema.
Fields
architecture: Option<String>The CPU architecture for which packages in this distribution channel were built.
cpe_uri: Option<String>Required. The cpe_uri in CPE format denoting the package manager version distributing a package.
description: Option<String>The distribution channel-specific description of this package.
latest_version: Option<Version>The latest available version of this package in this distribution channel.
maintainer: Option<String>A freeform string denoting the maintainer of this package.
url: Option<String>The distribution channel-specific homepage for this package.