pub struct FixableTotalByDigest {
pub fixable_count: Option<String>,
pub resource_uri: Option<String>,
pub severity: Option<String>,
pub total_count: Option<String>,
}Expand description
Per resource and severity counts of fixable and total vulnerabilities.
This type is not used in any activity, and only used as part of another schema.
Fields
fixable_count: Option<String>The number of fixable vulnerabilities associated with this resource.
resource_uri: Option<String>The affected resource.
severity: Option<String>The severity for this count. SEVERITY_UNSPECIFIED indicates total across all severities.
total_count: Option<String>The total number of vulnerabilities associated with this resource.