Struct google_containeranalysis1::api::GerritSourceContext
source · [−]pub struct GerritSourceContext {
pub alias_context: Option<AliasContext>,
pub gerrit_project: Option<String>,
pub host_uri: Option<String>,
pub revision_id: Option<String>,
}Expand description
A SourceContext referring to a Gerrit project.
This type is not used in any activity, and only used as part of another schema.
Fields
alias_context: Option<AliasContext>An alias, which may be a branch or tag.
gerrit_project: Option<String>The full project name within the host. Projects may be nested, so “project/subproject” is a valid project name. The “repo name” is the hostURI/project.
host_uri: Option<String>The URI of a running Gerrit instance.
revision_id: Option<String>A revision (commit) ID.