Struct google_containeranalysis1::api::ImageNote
source · pub struct ImageNote {
pub fingerprint: Option<Fingerprint>,
pub resource_url: Option<String>,
}Expand description
Basis describes the base image portion (Note) of the DockerImage relationship. Linked occurrences are derived from this or an equivalent image via: FROM Or an equivalent reference, e.g., a tag of the resource_url.
This type is not used in any activity, and only used as part of another schema.
Fields
fingerprint: Option<Fingerprint>Required. Immutable. The fingerprint of the base image.
resource_url: Option<String>Required. Immutable. The resource_url for the resource representing the basis of associated occurrence images.