Struct google_containeranalysis1::api::ImageOccurrence
source · [−]pub struct ImageOccurrence {
pub base_resource_url: Option<String>,
pub distance: Option<i32>,
pub fingerprint: Option<Fingerprint>,
pub layer_info: Option<Vec<Layer>>,
}Expand description
Details of the derived image portion of the DockerImage relationship. This image would be produced from a Dockerfile with FROM .
This type is not used in any activity, and only used as part of another schema.
Fields
base_resource_url: Option<String>Output only. This contains the base image URL for the derived image occurrence.
distance: Option<i32>Output only. The number of layers by which this image differs from the associated image basis.
fingerprint: Option<Fingerprint>Required. The fingerprint of the derived image.
layer_info: Option<Vec<Layer>>This contains layer-specific metadata, if populated it has length “distance” and is ordered with [distance] being the layer immediately following the base image and [1] being the final layer.