pub struct LayerDetails {
pub base_images: Option<Vec<BaseImage>>,
pub chain_id: Option<String>,
pub command: Option<String>,
pub diff_id: Option<String>,
pub index: Option<i32>,
}Expand description
Details about the layer a package was found in.
This type is not used in any activity, and only used as part of another schema.
Fields
base_images: Option<Vec<BaseImage>>The base images the layer is found within.
chain_id: Option<String>The layer chain ID (sha256 hash) of the layer in the container image. https://github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid
command: Option<String>The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built.
diff_id: Option<String>The diff ID (typically a sha256 hash) of the layer in the container image.
index: Option<i32>The index of the layer in the container image.