Struct google_containeranalysis1::api::ListNotesResponse
source · pub struct ListNotesResponse {
pub next_page_token: Option<String>,
pub notes: Option<Vec<Note>>,
}Expand description
Response for listing notes.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- notes list projects (response)
Fields
next_page_token: Option<String>The next pagination token in the list response. It should be used as page_token for the following request. An empty value means no more results.
notes: Option<Vec<Note>>The notes requested.