pub struct ListOccurrencesResponse {
pub next_page_token: Option<String>,
pub occurrences: Option<Vec<Occurrence>>,
}Expand description
Response for listing occurrences.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- occurrences list projects (response)
Fields
next_page_token: Option<String>The next pagination token in the list response. It should be used as page_token for the following request. An empty value means no more results.
occurrences: Option<Vec<Occurrence>>The occurrences requested.