Struct google_containeranalysis1::api::Location
source · pub struct Location {
pub cpe_uri: Option<String>,
pub path: Option<String>,
pub version: Option<Version>,
}Expand description
An occurrence of a particular package installation found within a system’s filesystem. E.g., glibc was found in /var/lib/dpkg/status.
This type is not used in any activity, and only used as part of another schema.
Fields
cpe_uri: Option<String>Deprecated. The CPE URI in CPE format
path: Option<String>The path from which we gathered that this package/version is installed.
version: Option<Version>Deprecated. The version installed at this location.