pub struct PackageIssue {
pub affected_cpe_uri: Option<String>,
pub affected_package: Option<String>,
pub affected_version: Option<Version>,
pub effective_severity: Option<String>,
pub file_location: Option<Vec<GrafeasV1FileLocation>>,
pub fix_available: Option<bool>,
pub fixed_cpe_uri: Option<String>,
pub fixed_package: Option<String>,
pub fixed_version: Option<Version>,
pub package_type: Option<String>,
}Expand description
A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).
This type is not used in any activity, and only used as part of another schema.
Fields
affected_cpe_uri: Option<String>Required. The CPE URI this vulnerability was found in.
affected_package: Option<String>Required. The package this vulnerability was found in.
affected_version: Option<Version>Required. The version of the package that is installed on the resource affected by this vulnerability.
effective_severity: Option<String>Output only. The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available.
file_location: Option<Vec<GrafeasV1FileLocation>>The location at which this package was found.
fix_available: Option<bool>Output only. Whether a fix is available for this package.
fixed_cpe_uri: Option<String>The CPE URI this vulnerability was fixed in. It is possible for this to be different from the affected_cpe_uri.
fixed_package: Option<String>The package this vulnerability was fixed in. It is possible for this to be different from the affected_package.
fixed_version: Option<Version>Required. The version of the package this vulnerability was fixed in. Setting this to VersionKind.MAXIMUM means no fix is yet available.
package_type: Option<String>The type of package (e.g. OS, MAVEN, GO).