pub struct PackageNote {
pub architecture: Option<String>,
pub cpe_uri: Option<String>,
pub description: Option<String>,
pub digest: Option<Vec<Digest>>,
pub distribution: Option<Vec<Distribution>>,
pub license: Option<License>,
pub maintainer: Option<String>,
pub name: Option<String>,
pub package_type: Option<String>,
pub url: Option<String>,
pub version: Option<Version>,
}Expand description
PackageNote represents a particular package version.
This type is not used in any activity, and only used as part of another schema.
Fields
architecture: Option<String>The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages.
cpe_uri: Option<String>The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages.
description: Option<String>The description of this package.
digest: Option<Vec<Digest>>Hash value, typically a file digest, that allows unique identification a specific package.
distribution: Option<Vec<Distribution>>Deprecated. The various channels by which a package is distributed.
license: Option<License>Licenses that have been declared by the authors of the package.
maintainer: Option<String>A freeform text denoting the maintainer of this package.
name: Option<String>Required. Immutable. The name of the package.
package_type: Option<String>The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).
url: Option<String>The homepage for this package.
version: Option<Version>The version of the package.