pub struct PackageOccurrence {
pub architecture: Option<String>,
pub cpe_uri: Option<String>,
pub license: Option<License>,
pub location: Option<Vec<Location>>,
pub name: Option<String>,
pub package_type: Option<String>,
pub version: Option<Version>,
}Expand description
Details on how a particular software package was installed on a system.
This type is not used in any activity, and only used as part of another schema.
Fields
architecture: Option<String>Output only. The CPU architecture for which packages in this distribution channel were built. Architecture will be blank for language packages.
cpe_uri: Option<String>Output only. The cpe_uri in CPE format denoting the package manager version distributing a package. The cpe_uri will be blank for language packages.
license: Option<License>Licenses that have been declared by the authors of the package.
location: Option<Vec<Location>>All of the places within the filesystem versions of this package have been found.
name: Option<String>Required. Output only. The name of the installed package.
package_type: Option<String>Output only. The type of package; whether native or non native (e.g., ruby gems, node.js packages, etc.).
version: Option<Version>Output only. The version of the package.