Struct google_containeranalysis1::api::ProjectMethods
source · [−]pub struct ProjectMethods<'a> { /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the ContainerAnalysis hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_containeranalysis1 as containeranalysis1;
use std::default::Default;
use containeranalysis1::{ContainerAnalysis, oauth2, hyper, hyper_rustls};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = ContainerAnalysis::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots().https_or_http().enable_http1().enable_http2().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `notes_batch_create(...)`, `notes_create(...)`, `notes_delete(...)`, `notes_get(...)`, `notes_get_iam_policy(...)`, `notes_list(...)`, `notes_occurrences_list(...)`, `notes_patch(...)`, `notes_set_iam_policy(...)`, `notes_test_iam_permissions(...)`, `occurrences_batch_create(...)`, `occurrences_create(...)`, `occurrences_delete(...)`, `occurrences_get(...)`, `occurrences_get_iam_policy(...)`, `occurrences_get_notes(...)`, `occurrences_get_vulnerability_summary(...)`, `occurrences_list(...)`, `occurrences_patch(...)`, `occurrences_set_iam_policy(...)` and `occurrences_test_iam_permissions(...)`
// to build up your call.
let rb = hub.projects();Implementations
sourceimpl<'a> ProjectMethods<'a>
impl<'a> ProjectMethods<'a>
sourcepub fn notes_occurrences_list(
&self,
name: &str
) -> ProjectNoteOccurrenceListCall<'a>
pub fn notes_occurrences_list(
&self,
name: &str
) -> ProjectNoteOccurrenceListCall<'a>
Create a builder to help you perform the following task:
Lists occurrences referencing the specified note. Provider projects can use this method to get all occurrences across consumer projects referencing the specified note.
Arguments
name- Required. The name of the note to list occurrences for in the form ofprojects/[PROVIDER_ID]/notes/[NOTE_ID].
sourcepub fn notes_batch_create(
&self,
request: BatchCreateNotesRequest,
parent: &str
) -> ProjectNoteBatchCreateCall<'a>
pub fn notes_batch_create(
&self,
request: BatchCreateNotesRequest,
parent: &str
) -> ProjectNoteBatchCreateCall<'a>
Create a builder to help you perform the following task:
Creates new notes in batch.
Arguments
request- No description provided.parent- Required. The name of the project in the form ofprojects/[PROJECT_ID], under which the notes are to be created.
sourcepub fn notes_create(
&self,
request: Note,
parent: &str
) -> ProjectNoteCreateCall<'a>
pub fn notes_create(
&self,
request: Note,
parent: &str
) -> ProjectNoteCreateCall<'a>
Create a builder to help you perform the following task:
Creates a new note.
Arguments
request- No description provided.parent- Required. The name of the project in the form ofprojects/[PROJECT_ID], under which the note is to be created.
sourcepub fn notes_delete(&self, name: &str) -> ProjectNoteDeleteCall<'a>
pub fn notes_delete(&self, name: &str) -> ProjectNoteDeleteCall<'a>
Create a builder to help you perform the following task:
Deletes the specified note.
Arguments
name- Required. The name of the note in the form ofprojects/[PROVIDER_ID]/notes/[NOTE_ID].
sourcepub fn notes_get(&self, name: &str) -> ProjectNoteGetCall<'a>
pub fn notes_get(&self, name: &str) -> ProjectNoteGetCall<'a>
Create a builder to help you perform the following task:
Gets the specified note.
Arguments
name- Required. The name of the note in the form ofprojects/[PROVIDER_ID]/notes/[NOTE_ID].
sourcepub fn notes_get_iam_policy(
&self,
request: GetIamPolicyRequest,
resource: &str
) -> ProjectNoteGetIamPolicyCall<'a>
pub fn notes_get_iam_policy(
&self,
request: GetIamPolicyRequest,
resource: &str
) -> ProjectNoteGetIamPolicyCall<'a>
Create a builder to help you perform the following task:
Gets the access control policy for a note or an occurrence resource. Requires containeranalysis.notes.setIamPolicy or containeranalysis.occurrences.setIamPolicy permission if the resource is a note or occurrence, respectively. The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being requested. See the operation documentation for the appropriate value for this field.
sourcepub fn notes_list(&self, parent: &str) -> ProjectNoteListCall<'a>
pub fn notes_list(&self, parent: &str) -> ProjectNoteListCall<'a>
Create a builder to help you perform the following task:
Lists notes for the specified project.
Arguments
parent- Required. The name of the project to list notes for in the form ofprojects/[PROJECT_ID].
sourcepub fn notes_patch(&self, request: Note, name: &str) -> ProjectNotePatchCall<'a>
pub fn notes_patch(&self, request: Note, name: &str) -> ProjectNotePatchCall<'a>
Create a builder to help you perform the following task:
Updates the specified note.
Arguments
request- No description provided.name- Required. The name of the note in the form ofprojects/[PROVIDER_ID]/notes/[NOTE_ID].
sourcepub fn notes_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str
) -> ProjectNoteSetIamPolicyCall<'a>
pub fn notes_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str
) -> ProjectNoteSetIamPolicyCall<'a>
Create a builder to help you perform the following task:
Sets the access control policy on the specified note or occurrence. Requires containeranalysis.notes.setIamPolicy or containeranalysis.occurrences.setIamPolicy permission if the resource is a note or an occurrence, respectively. The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being specified. See the operation documentation for the appropriate value for this field.
sourcepub fn notes_test_iam_permissions(
&self,
request: TestIamPermissionsRequest,
resource: &str
) -> ProjectNoteTestIamPermissionCall<'a>
pub fn notes_test_iam_permissions(
&self,
request: TestIamPermissionsRequest,
resource: &str
) -> ProjectNoteTestIamPermissionCall<'a>
Create a builder to help you perform the following task:
Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, containeranalysis.notes.list). The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy detail is being requested. See the operation documentation for the appropriate value for this field.
sourcepub fn occurrences_batch_create(
&self,
request: BatchCreateOccurrencesRequest,
parent: &str
) -> ProjectOccurrenceBatchCreateCall<'a>
pub fn occurrences_batch_create(
&self,
request: BatchCreateOccurrencesRequest,
parent: &str
) -> ProjectOccurrenceBatchCreateCall<'a>
Create a builder to help you perform the following task:
Creates new occurrences in batch.
Arguments
request- No description provided.parent- Required. The name of the project in the form ofprojects/[PROJECT_ID], under which the occurrences are to be created.
sourcepub fn occurrences_create(
&self,
request: Occurrence,
parent: &str
) -> ProjectOccurrenceCreateCall<'a>
pub fn occurrences_create(
&self,
request: Occurrence,
parent: &str
) -> ProjectOccurrenceCreateCall<'a>
Create a builder to help you perform the following task:
Creates a new occurrence.
Arguments
request- No description provided.parent- Required. The name of the project in the form ofprojects/[PROJECT_ID], under which the occurrence is to be created.
sourcepub fn occurrences_delete(&self, name: &str) -> ProjectOccurrenceDeleteCall<'a>
pub fn occurrences_delete(&self, name: &str) -> ProjectOccurrenceDeleteCall<'a>
Create a builder to help you perform the following task:
Deletes the specified occurrence. For example, use this method to delete an occurrence when the occurrence is no longer applicable for the given resource.
Arguments
name- Required. The name of the occurrence in the form ofprojects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID].
sourcepub fn occurrences_get(&self, name: &str) -> ProjectOccurrenceGetCall<'a>
pub fn occurrences_get(&self, name: &str) -> ProjectOccurrenceGetCall<'a>
Create a builder to help you perform the following task:
Gets the specified occurrence.
Arguments
name- Required. The name of the occurrence in the form ofprojects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID].
sourcepub fn occurrences_get_iam_policy(
&self,
request: GetIamPolicyRequest,
resource: &str
) -> ProjectOccurrenceGetIamPolicyCall<'a>
pub fn occurrences_get_iam_policy(
&self,
request: GetIamPolicyRequest,
resource: &str
) -> ProjectOccurrenceGetIamPolicyCall<'a>
Create a builder to help you perform the following task:
Gets the access control policy for a note or an occurrence resource. Requires containeranalysis.notes.setIamPolicy or containeranalysis.occurrences.setIamPolicy permission if the resource is a note or occurrence, respectively. The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being requested. See the operation documentation for the appropriate value for this field.
sourcepub fn occurrences_get_notes(
&self,
name: &str
) -> ProjectOccurrenceGetNoteCall<'a>
pub fn occurrences_get_notes(
&self,
name: &str
) -> ProjectOccurrenceGetNoteCall<'a>
Create a builder to help you perform the following task:
Gets the note attached to the specified occurrence. Consumer projects can use this method to get a note that belongs to a provider project.
Arguments
name- Required. The name of the occurrence in the form ofprojects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID].
sourcepub fn occurrences_get_vulnerability_summary(
&self,
parent: &str
) -> ProjectOccurrenceGetVulnerabilitySummaryCall<'a>
pub fn occurrences_get_vulnerability_summary(
&self,
parent: &str
) -> ProjectOccurrenceGetVulnerabilitySummaryCall<'a>
Create a builder to help you perform the following task:
Gets a summary of the number and severity of occurrences.
Arguments
parent- Required. The name of the project to get a vulnerability summary for in the form ofprojects/[PROJECT_ID].
sourcepub fn occurrences_list(&self, parent: &str) -> ProjectOccurrenceListCall<'a>
pub fn occurrences_list(&self, parent: &str) -> ProjectOccurrenceListCall<'a>
Create a builder to help you perform the following task:
Lists occurrences for the specified project.
Arguments
parent- Required. The name of the project to list occurrences for in the form ofprojects/[PROJECT_ID].
sourcepub fn occurrences_patch(
&self,
request: Occurrence,
name: &str
) -> ProjectOccurrencePatchCall<'a>
pub fn occurrences_patch(
&self,
request: Occurrence,
name: &str
) -> ProjectOccurrencePatchCall<'a>
Create a builder to help you perform the following task:
Updates the specified occurrence.
Arguments
request- No description provided.name- Required. The name of the occurrence in the form ofprojects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID].
sourcepub fn occurrences_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str
) -> ProjectOccurrenceSetIamPolicyCall<'a>
pub fn occurrences_set_iam_policy(
&self,
request: SetIamPolicyRequest,
resource: &str
) -> ProjectOccurrenceSetIamPolicyCall<'a>
Create a builder to help you perform the following task:
Sets the access control policy on the specified note or occurrence. Requires containeranalysis.notes.setIamPolicy or containeranalysis.occurrences.setIamPolicy permission if the resource is a note or an occurrence, respectively. The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy is being specified. See the operation documentation for the appropriate value for this field.
sourcepub fn occurrences_test_iam_permissions(
&self,
request: TestIamPermissionsRequest,
resource: &str
) -> ProjectOccurrenceTestIamPermissionCall<'a>
pub fn occurrences_test_iam_permissions(
&self,
request: TestIamPermissionsRequest,
resource: &str
) -> ProjectOccurrenceTestIamPermissionCall<'a>
Create a builder to help you perform the following task:
Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, containeranalysis.notes.list). The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.
Arguments
request- No description provided.resource- REQUIRED: The resource for which the policy detail is being requested. See the operation documentation for the appropriate value for this field.