pub struct SlsaProvenance {
    pub builder: Option<SlsaBuilder>,
    pub materials: Option<Vec<Material>>,
    pub metadata: Option<SlsaMetadata>,
    pub recipe: Option<SlsaRecipe>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

builder: Option<SlsaBuilder>

required

materials: Option<Vec<Material>>

The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on. This is considered to be incomplete unless metadata.completeness.materials is true. Unset or null is equivalent to empty.

metadata: Option<SlsaMetadata>

no description provided

recipe: Option<SlsaRecipe>

Identifies the configuration used for the build. When combined with materials, this SHOULD fully describe the build, such that re-running this recipe results in bit-for-bit identical output (if the build is reproducible). required