pub struct WindowsUpdate {
    pub categories: Option<Vec<Category>>,
    pub description: Option<String>,
    pub identity: Option<Identity>,
    pub kb_article_ids: Option<Vec<String>>,
    pub last_published_timestamp: Option<String>,
    pub support_url: Option<String>,
    pub title: Option<String>,
}
Windows Update represents the metadata about the update for the Windows operating system. The fields in this message come from the Windows Update API documented at https://docs.microsoft.com/en-us/windows/win32/api/wuapi/nn-wuapi-iupdate.

This type is not used in any activity, and only used as part of another schema.

Fields

categories: Option<Vec<Category>>

The list of categories to which the update belongs.

description: Option<String>

The localized description of the update.

identity: Option<Identity>

Required - The unique identifier for the update.

kb_article_ids: Option<Vec<String>>

The Microsoft Knowledge Base article IDs that are associated with the update.

last_published_timestamp: Option<String>

The last published timestamp of the update.

support_url: Option<String>

The hyperlink to the support information for the update.

title: Option<String>

The localized title of the update.